@@ -29,12 +29,12 @@ module GetArgs
 
     # required args
     if (args_node.args && args_node.args.size > 0)
-      required << args_node.args.child_nodes.map { |arg| [arg.name.to_s.intern] }
+      required = args_node.args.child_nodes.map { |arg| [arg.name.to_s.intern] }
     end
   
     # optional args
     if (args_node.opt_args && args_node.opt_args.size > 0)
-      optional << args_node.opt_args.child_nodes.map do |arg|
+      optional = args_node.opt_args.child_nodes.map do |arg|
         name = arg.name.to_s.intern
         value_node = arg.value_node
         case value_node
@@ -51,17 +51,7 @@ module GetArgs
       end
     end
 
-    first_args = required.first
-    optional.first.each {|arg| first_args << arg} if optional.first
-        
-    args = [first_args]
-    
-    rest = args_node.rest_arg_node
-    args << (rest ? rest.name.to_s.intern : nil)
-  
-    block = args_node.block_arg_node
-    args << (block ? block.name.to_s.intern : nil)
-
-    args
+    args = required + optional
+    return [args, optional.map{|name,| name}]
   end
-end
\ No newline at end of file
+end
