@@ -1,11 +1,23 @@
-require File.dirname(__FILE__) + '/spec_helper'
+require 'spec_helper'
 
 describe "ActionArgs" do
   
   it "should not accidently introduce any methods as controller actions" do
     Merb::Controller.callable_actions.should be_empty
   end
-  
+
+  it "should extract explicit one arg" do
+    ActionArgs.instance_method(:index).get_args.should == [[[:foo]], []]
+  end
+
+  it "should extract explicit multi args" do
+    ActionArgs.instance_method(:multi).get_args.should == [[[:foo], [:bar]], []]
+  end
+
+  it "should extract optional args" do
+    ActionArgs.instance_method(:with_default_nil).get_args.should == [[[:foo], [:bar, nil]], [:bar]]
+  end
+
 end
 
 describe Merb::AbstractController do
@@ -64,4 +76,4 @@ describe Merb::AbstractController do
       Merb::ControllerExceptions::BadRequest, /were missing bar/)          
   end
   
-end
\ No newline at end of file
+end
